@@ -13,12 +13,12 @@ class Krawtchouk(OrthogonalPolynomialsGenerator):
         p (float or sympy.Symbol): parameter of Krawtchouk polynomials
     """
 
-    def __init__(self, x, N, p):
+    def __init__(self, N, p, x=Symbol('x')):
         if not (isinstance(N, int) and N > 0):
             warn("The size N should be an integer positive number (int).")
         if not (isinstance(p, Symbol) or (isinstance(p, float) and p > 0 and p < 1)):
             warn("The parameter p should be a real number in ]0,1[ (float) or a sympy.Symbol.")
-        super().__init__(x, [N, p])
+        super().__init__([N, p], x)
 
 
     def __str__(self):
